/*
 *  Copyright (C) 2002  Harald Barth, Stockholm, Sweden.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 */
#include "consist.h"
RCSID("$Id: port.c,v 1.1 2002/01/01 13:00:48 haba Exp $");

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>
#include <unistd.h>
#include "port.h"

int portOpen(char *hostname, int port)
{
  struct hostent *serverHost;
  struct sockaddr_in socketAddr;
  int descriptor;

  bzero(&socketAddr, sizeof(socketAddr));
  if ((serverHost = gethostbyname(hostname)) == NULL) {
    return -1;
  }      
  socketAddr.sin_family = serverHost->h_addrtype;
  memcpy(&socketAddr.sin_addr, 
	 serverHost->h_addr_list[0],
	 sizeof(socketAddr.sin_addr));
  socketAddr.sin_port = htons(port);
  if ((descriptor = socket(AF_INET, SOCK_STREAM, 0)) == -1) {
    return -1;
  }
  if (connect(descriptor, 
	      (struct sockaddr *)&socketAddr, 
	      sizeof(socketAddr)) < 0 ) {
    return -1;
  }
  return descriptor;
}

int portReadLine(int socket, char *line, int maxlen){
  
  int pos=0;
  char z;
  int byteCount;

  for (pos = 0; pos < maxlen - 1; pos++) {
    byteCount=read(socket, &z, 1);
    if(byteCount != 1) /* We asked for exactly one */
      return -1;
    line[pos] = z;
    switch (z) {
      /* List end delimiter chars here */
    case 0x0a:
      line[pos + 1] = 0;
      return pos + 1;
      /* Null character not allowed */
    case 0:
      return -1;
    }
  }
  return -1; /* did not find end delimiter in string */
}

int portWrite(int socket, char *line) {

  return write(socket, line, strlen(line));
}
